server_client_20141211_175217

### config1 : test_race_condition

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 1.04861807823 sec | 4.1797709465 sec

Error message: Race condition fail

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
qps | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 4.00 | 0.0
latency | 0.32 | 0.29 | 0.25 | 0.3 | 0.31 | 0.31 | 0.32 | 0.32 | 0.024

#### client2-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0
latency | 23.14 | 23.14 | 23.14 | 23.14 | 23.14 | 23.14 | 23.14 | 23.14 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.297
server1-perf | latency | mean lt 0.33 | 0.29175
server1-perf | qps | mean lt 7.0 | 4.0
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | None
client1-perf | latency | mean lt 35.0 | None
client1-perf | qps | mean lt 2.0 | None
client2-perf | latency | p50 lt 22.0 | 23.137
client2-perf | latency | mean lt 35.0 | 23.137
client2-perf | qps | mean lt 2.0 | 1.0